==> valknut-0.4.0a.tar.bz2: valknut-0.4.0a/valknut/dctranslator.h <==
/***************************************************************************
                          dctranslator.h  -  description
                             -------------------
    begin                : Die Nov 19 2002
    copyright            : (C) 2002 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DCTRANSLATOR_H
#define DCTRANSLATOR_H

#include <qobject.h>
#include <dclib/core/cstringlist.h>
#include <QStringList>
#include <QHttp>

class QComboBox;
class QWidget;
class QGroupBox;

/**
  *@author Mathias Kster
  */

class DCTranslator : public QObject  {
Q_OBJECT

public: 
	/** construtor */
	DCTranslator(QWidget *parent=0, const char *name=0);
	/** destructor */
	virtual ~DCTranslator();

	/** */
	void InitDocument();

	/** */
	QString SelectLanguage( CString lang, QWidget * parent = 0 );
	/** */
	bool Translate( QObject * sender, QString lang, QString text );

private:
	/** */
	QString GetUserAgent() const;
	/** */
	QHttp * pHttp;
	/** It maps QHttp request IDs to the DC_TranslationEvent object */
	CStringList m_RequestList;
	/** */
	QString m_sLanguage;
	/** Just in case you need to GET a page before you are allowed to do a POST request */
	/* int m_nGetRequestID; */
	/** Just in case you need to GET a page before you are allowed to do a POST request */
	/* bool m_bReady; */
	/** */
	QString provider;
	/** */
	QComboBox * m_pComboBoxProvider;
	/** */
	QGroupBox * m_pGroupBoxYahoo;
	/** */
	QGroupBox * m_pGroupBoxGoogle;
	/** */
	QStringList langs_ys;
	/** */
	QStringList langs_y;
	/** */
	QStringList langs_gs_from;
	/** */
	QStringList langs_g_from;
	/** */
	QStringList langs_gs_to;
	/** */
	QStringList langs_g_to;

private slots:
	/** */
	/* void slotDataReadProgress( int bytesDone, int bytesTotal ); */
	/** */
	/* void slotGetRequestFinished( int id, bool error ); */
	/** */
	void slotPostRequestFinished( int id, bool error );
	/** */
	void slotProviderChanged( int index );
};

extern DCTranslator * g_pTranslator;
#endif

==> valknut-0.4.4.tar.bz2: valknut-0.4.4/valknut/dctranslator.h <==
/***************************************************************************
                          dctranslator.h  -  description
                             -------------------
    begin                : Die Nov 19 2002
    copyright            : (C) 2002 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DCTRANSLATOR_H
#define DCTRANSLATOR_H

#include <qobject.h>
#include <QStringList>
#include <QHash>

class QHttp;
class QComboBox;
class QWidget;
class QGroupBox;
class DC_TranslationEvent;

/**
  *@author Mathias Kster
  */

class DCTranslator : public QObject  {
Q_OBJECT

public: 
	/** construtor */
	DCTranslator(QWidget *parent=0, const char *name=0);
	/** destructor */
	virtual ~DCTranslator();

	/** */
	void InitDocument();

	/** */
	QString SelectLanguage( QString lang, QWidget * parent = 0 );
	/** */
	bool Translate( QObject * sender, QString lang, QString text );

private:
	/** */
	QString GetUserAgent() const;
	/** */
	QHttp * pHttp;
	/** It maps QHttp request IDs to the DC_TranslationEvent object */
	QHash<int, DC_TranslationEvent*> m_RequestHash;
	/** */
	QString m_sLanguage;
	/** Just in case you need to GET a page before you are allowed to do a POST request */
	/* int m_nGetRequestID; */
	/** Just in case you need to GET a page before you are allowed to do a POST request */
	/* bool m_bReady; */
	/** */
	QString provider;
	/** */
	QComboBox * m_pComboBoxProvider;
	/** */
	QGroupBox * m_pGroupBoxYahoo;
	/** */
	QGroupBox * m_pGroupBoxGoogle;
	/** */
	QStringList langs_ys;
	/** */
	QStringList langs_y;
	/** */
	QStringList langs_gs_from;
	/** */
	QStringList langs_g_from;
	/** */
	QStringList langs_gs_to;
	/** */
	QStringList langs_g_to;

private slots:
	/** */
	/* void slotDataReadProgress( int bytesDone, int bytesTotal ); */
	/** */
	/* void slotGetRequestFinished( int id, bool error ); */
	/** */
	void slotPostRequestFinished( int id, bool error );
	/** */
	void slotProviderChanged( int index );
};

extern DCTranslator * g_pTranslator;
#endif
